[tor-commits] [tor/master] Remove or_circuit_t.is_first_hop; use channel_is_client() instead

nickm at torproject.org nickm at torproject.org
Fri Sep 22 13:00:57 UTC 2017


commit 66aff2d8f35217cc802bd46eeeaf49326d7de4b0
Author: Nick Mathewson <nickm at torproject.org>
Date:   Wed Sep 6 14:39:40 2017 -0400

    Remove or_circuit_t.is_first_hop; use channel_is_client() instead
    
    The is_first_hop field should have been called used_create_fast,
    but everywhere that we wanted to check it, we should have been
    checking channel_is_client() instead.
---
 src/or/circuitbuild.c    | 4 ++--
 src/or/circuituse.c      | 6 +++---
 src/or/connection_edge.c | 9 +++++----
 src/or/or.h              | 3 ---
 4 files changed, 10 insertions(+), 12 deletions(-)

diff --git a/src/or/circuitbuild.c b/src/or/circuitbuild.c
index 65cd7bd5d..e614c3f28 100644
--- a/src/or/circuitbuild.c
+++ b/src/or/circuitbuild.c
@@ -1611,12 +1611,12 @@ onionskin_answer(or_circuit_t *circ,
 
   memcpy(circ->rend_circ_nonce, rend_circ_nonce, DIGEST_LEN);
 
-  circ->is_first_hop = (created_cell->cell_type == CELL_CREATED_FAST);
+  int used_create_fast = (created_cell->cell_type == CELL_CREATED_FAST);
 
   append_cell_to_circuit_queue(TO_CIRCUIT(circ),
                                circ->p_chan, &cell, CELL_DIRECTION_IN, 0);
   log_debug(LD_CIRC,"Finished sending '%s' cell.",
-            circ->is_first_hop ? "created_fast" : "created");
+            used_create_fast ? "created_fast" : "created");
 
   /* Ignore the local bit when ExtendAllowPrivateAddresses is set:
    * it violates the assumption that private addresses are local.
diff --git a/src/or/connection_edge.c b/src/or/connection_edge.c
index a9fdeee0e..82dad60fc 100644
--- a/src/or/connection_edge.c
+++ b/src/or/connection_edge.c
@@ -3413,7 +3413,8 @@ connection_exit_begin_conn(cell_t *cell, circuit_t *circ)
     port = bcell.port;
 
     if (or_circ && or_circ->p_chan) {
-      if ((or_circ->is_first_hop ||
+      const int client_chan = channel_is_client(or_circ->p_chan);
+      if ((client_chan ||
            (!connection_or_digest_is_known_relay(
                 or_circ->p_chan->identity_digest) &&
           should_refuse_unknown_exits(options)))) {
@@ -3423,10 +3424,10 @@ connection_exit_begin_conn(cell_t *cell, circuit_t *circ)
         log_fn(LOG_PROTOCOL_WARN, LD_PROTOCOL,
                "Attempt by %s to open a stream %s. Closing.",
                safe_str(channel_get_canonical_remote_descr(or_circ->p_chan)),
-               or_circ->is_first_hop ? "on first hop of circuit" :
-                                       "from unknown relay");
+               client_chan ? "on first hop of circuit" :
+                             "from unknown relay");
         relay_send_end_cell_from_edge(rh.stream_id, circ,
-                                      or_circ->is_first_hop ?
+                                      client_chan ?
                                         END_STREAM_REASON_TORPROTOCOL :
                                         END_STREAM_REASON_MISC,
                                       NULL);
diff --git a/src/or/or.h b/src/or/or.h
index b3cd83f24..2712ac3e5 100644
--- a/src/or/or.h
+++ b/src/or/or.h
@@ -3459,9 +3459,6 @@ typedef struct or_circuit_t {
   /* We have already received an INTRODUCE1 cell on this circuit. */
   unsigned int already_received_introduce1 : 1;
 
-  /** True iff this circuit was made with a CREATE_FAST cell. */
-  unsigned int is_first_hop : 1;
-
   /** If set, this circuit carries HS traffic. Consider it in any HS
    *  statistics. */
   unsigned int circuit_carries_hs_traffic_stats : 1;





More information about the tor-commits mailing list
diff --git a/src/or/circuituse.c b/src/or/circuituse.c
index 570b05e57..6a4597987 100644
--- a/src/or/circuituse.c
+++ b/src/or/circuituse.c
@@ -1514,7 +1514,7 @@ circuit_expire_old_circuits_clientside(void)
 #define IDLE_ONE_HOP_CIRC_TIMEOUT 60
 
 /** Find each non-origin circuit that has been unused for too long,
  * has no streams on it, used a create_fast, and ends here: mark it
  * for close.
  */
 void
@@ -1530,9 +1530,9 @@ circuit_expire_old_circuits_serverside(time_t now)
     /* If the circuit has been idle for too long, and there are no streams
      * on it, and it ends here, and it used a create_fast, mark it for close.
      */
-    if (or_circ->is_first_hop && !circ->n_chan &&
+    if (or_circ->p_chan && channel_is_client(or_circ->p_chan) &&
+        !circ->n_chan &&
         !or_circ->n_streams && !or_circ->resolving_streams &&
-        or_circ->p_chan &&
         channel_when_last_xmit(or_circ->p_chan) <= cutoff) {
       log_info(LD_CIRC, "Closing circ_id %u (empty %d secs ago)",
                (unsigned)or_circ->p_circ_id,
@@ -1514,7 +1514,7 @@ circuit_expire_old_circuits_clientside(void)
 
 /** Find each non-origin circuit that has been unused for too long,
- * has no streams on it, used a create_fast, and ends here: mark it
+ * has no streams on it, came from a client, and ends here: mark it
  * for close.
  */